@@ -1,23 +1,13 @@
 // This is copyrighted software. More information is at the end of this file.
 #pragma once
 
-// FIXME: That's dumb. We should add actual print functions instead of wrapping the std streams.
-#include <iostream>
-
 #ifdef AULIB_DEBUG
 #    include <cassert>
 #    define AM_debugAssert assert
-#    define AM_debugPrint(x) std::cerr << x
-#    define AM_debugPrintLn(x) AM_debugPrint(x) << '\n'
 #else
 #    define AM_debugAssert(x)
-#    define AM_debugPrintLn(x)
-#    define AM_debugPrint(x)
 #endif
 
-#define AM_warn(x) std::cerr << x
-#define AM_warnLn(x) std::cerr << x << '\n'
-
 /*
 
 Copyright (C) 2014, 2015, 2016, 2017, 2018, 2019 Nikos Chantziaras.
